==> rfacebookstat_2.0.1.tar.gz: rfacebookstat/NEWS.md <==
# rfacebookstat 2.0.1

Дата релиза: 2020-02-07

Пакет переведён на работу с API версии v6.0. Фактически на стороне Facebook Marketing API никаких изменений не было, единственное, что изменилось это значение опции *rfacebookstat.api_version* по умолчанию.


# rfacebookstat 2.0.0

Дата релиза: 2019-12-17

* Новые функции
    * `fbAuth()` - Новая функция авторизации, подробности в разеле **Авторизация**.
    * `fbGetUserAdAccounts()` - Загрузка списка аккаунтов к которым есть доступ у определённого пользователя facebook.
	* `fbGetAdAccountsConversions()` - Получить список конвесий настроенных в рекламной аккаунте.
	* `fbGetAdVideos()` - Загрузка списка видео из рекламного аккаунта
	* `fbGetSettings()` - Вывести в консоль все применённые в пакете настройки.

* Доработанные функции
    * В функцию `fbGetMarketingStat()` добавлен аргумент *attribution_window* с помощью которого вы можете запрашивать поле *actions* и применять к нему различные окна атрибуции.
    * Так же был полностью переписан процесс разворачивания вложенных полей типа *actions*, и прочих. Теперь функция `fbGetMarketingStat()` работает с ними более стабильно.
	* Изменения в функциях `fbGetApps()` и `fbGetPages()` теперь вы можете запрашивать список продвигаемых страниц и приложений непосредственно из рекламных аккаунтов. 
	    * Теперь вы можете запрашивать список страниц и приложений из конкретного аккаунта, используя аргумент *accounts_id*. Это новый аргумент который был добавлен вместо устаревшего *projects_id*.
		* В обеих функциях значительно расширен список полей которые они возвращают.
	* В большинстве функций аргумент *accounts_id* больше не является обязательным, и по умолчанию запрашивает данные по всем рекламным аккаунтам к которым у вас есть доступ, эта доработка коснулась следующих функций:
	    * `fbGetCampaigns()`
		* `fbGetAdSets()`
		* `fbGetAds()`
		* `fbGetAdCreative()`
		* `fbGetApps()`
		* `fbGetPages()`
		* `fbGetAdAccountUsersPermissions()`
		* `fbGetAdAccountUsers()`
		
* Удалённые функции
    * Из пакета полностью удалена функция `fbGetProjects()`, в связи с тем, что в Facebook больше не существует проектов.

* Авторизация
    * Был значительно улучшен процесс авторизации, теперь помимо опций вы можете использовать переменные среды.
    * Так же при авторизации начиная с версии 2.0.0 учётные данные сохраняются в локальный файл, и по умолчанию вы получаете долгосрочный токен.
	* В пакет встроено собственное приложение, теперь нет необходимости регистрировать собственное приложение и запрашивать стандартнй доступ к API, он уже по умолчанию вшит в пакет.
	
* Документация
    * В виньетку по загрузке статистики добавлена информация про окна атрибуции: `vignette('rfacebookstat-get-statistics', package = 'rfacebookstat')`
	* В пакет добавлена новая виньетка посвящённая процессу авторизации и его автоматизации:  `vignette('rfacebookstat-authorization', package = 'rfacebookstat')`
	
* Прочее
    * Пакет переведён на работу с версией API v5.0.


# rfacebookstat 1.10.0

Дата релиза: 2019-09-10

* Пакет переведён на работу с API V4.0
* Добавлена новая функция `fbGetBusinessUserAdAccounts()`, позволяющая загрузить по пользователю бизнесс менеджера список аккаунтов к которому ему предоставлен доступ.


# rfacebookstat 1.9.1

Исправлена виньетка


# rfacebookstat 1.9.0

Дата релиза: 2019-05-21

CСсылка на подробное описание релиза: [Link](https://github.com/selesnow/rfacebookstat/releases/tag/1.9.0)

## Что нового

* Новая функция `fbGetCatalogs` предназначенная для загрузки каталогов;
* Опции, для упрощения и компактности синтаксиса в пакет добавлены 4 опции
    * rfacebookstat.api_version - Версия API, по умолчанию v3.3
	* rfacebookstat.access_token - Токен доступа к API
	* rfacebookstat.accounts_id - ID рекламного аккаунта
	* rfacebookstat.business_id - ID бизнес менеджера
* Упрощённый формат фильтрации данных, пример `"impressions LESS_THAN 5000"`;
* Исправлена ошибка возникающая при загрузке action и применения action_breakdowns;
* В пакет добавлена виньетка посвящённая загрузки статистики из рекламных аккаунтов Facebook: `vignette('rfacebookstat-get-statistics', package = 'rfacebookstat')`;
* Добавлен обработчик лимитов API;
* В результат возвращаемый функцией `fbGetAdCreative` добавлено поле *link_nested* с данными по дочерним ссылкам из кольцевой галереи.

==> rfacebookstat_2.0.3.tar.gz: rfacebookstat/NEWS.md <==
# rfacebookstat 2.0.3

Дата релиза: 2020-05-06

Исправлена ошибка в функции `fbGetAdCreative()`, ранее не парсились ссылки, хеши миниатюр и сообщения в видео креативах. 
Также в результат возвращаемый данной функцией добавлены поляЖ

* object_type - Тип объекта
* video_id - Идентификатор видео

# rfacebookstat 2.0.2

Дата релиза: 2020-03-24

Исправлены некоторые проблемы которые возникали у пользоваталей при авторизации через стандартное приложение.

Добавлена скритая функция `fbRevokeAppPrivilegies()`, с помощью которой вы можете отозвать выданные приложению разрешения.

# rfacebookstat 2.0.1

Дата релиза: 2020-02-07

Пакет переведён на работу с API версии v6.0. Фактически на стороне Facebook Marketing API никаких изменений не было, единственное, что изменилось это значение опции *rfacebookstat.api_version* по умолчанию.


# rfacebookstat 2.0.0

Дата релиза: 2019-12-17

* Новые функции
    * `fbAuth()` - Новая функция авторизации, подробности в разеле **Авторизация**.
    * `fbGetUserAdAccounts()` - Загрузка списка аккаунтов к которым есть доступ у определённого пользователя facebook.
	* `fbGetAdAccountsConversions()` - Получить список конвесий настроенных в рекламной аккаунте.
	* `fbGetAdVideos()` - Загрузка списка видео из рекламного аккаунта
	* `fbGetSettings()` - Вывести в консоль все применённые в пакете настройки.

* Доработанные функции
    * В функцию `fbGetMarketingStat()` добавлен аргумент *attribution_window* с помощью которого вы можете запрашивать поле *actions* и применять к нему различные окна атрибуции.
    * Так же был полностью переписан процесс разворачивания вложенных полей типа *actions*, и прочих. Теперь функция `fbGetMarketingStat()` работает с ними более стабильно.
	* Изменения в функциях `fbGetApps()` и `fbGetPages()` теперь вы можете запрашивать список продвигаемых страниц и приложений непосредственно из рекламных аккаунтов. 
	    * Теперь вы можете запрашивать список страниц и приложений из конкретного аккаунта, используя аргумент *accounts_id*. Это новый аргумент который был добавлен вместо устаревшего *projects_id*.
		* В обеих функциях значительно расширен список полей которые они возвращают.
	* В большинстве функций аргумент *accounts_id* больше не является обязательным, и по умолчанию запрашивает данные по всем рекламным аккаунтам к которым у вас есть доступ, эта доработка коснулась следующих функций:
	    * `fbGetCampaigns()`
		* `fbGetAdSets()`
		* `fbGetAds()`
		* `fbGetAdCreative()`
		* `fbGetApps()`
		* `fbGetPages()`
		* `fbGetAdAccountUsersPermissions()`
		* `fbGetAdAccountUsers()`
		
* Удалённые функции
    * Из пакета полностью удалена функция `fbGetProjects()`, в связи с тем, что в Facebook больше не существует проектов.

* Авторизация
    * Был значительно улучшен процесс авторизации, теперь помимо опций вы можете использовать переменные среды.
    * Так же при авторизации начиная с версии 2.0.0 учётные данные сохраняются в локальный файл, и по умолчанию вы получаете долгосрочный токен.
	* В пакет встроено собственное приложение, теперь нет необходимости регистрировать собственное приложение и запрашивать стандартнй доступ к API, он уже по умолчанию вшит в пакет.
	
* Документация
    * В виньетку по загрузке статистики добавлена информация про окна атрибуции: `vignette('rfacebookstat-get-statistics', package = 'rfacebookstat')`
	* В пакет добавлена новая виньетка посвящённая процессу авторизации и его автоматизации:  `vignette('rfacebookstat-authorization', package = 'rfacebookstat')`
	
* Прочее
    * Пакет переведён на работу с версией API v5.0.


# rfacebookstat 1.10.0

Дата релиза: 2019-09-10

* Пакет переведён на работу с API V4.0
* Добавлена новая функция `fbGetBusinessUserAdAccounts()`, позволяющая загрузить по пользователю бизнесс менеджера список аккаунтов к которому ему предоставлен доступ.


# rfacebookstat 1.9.1

Исправлена виньетка


# rfacebookstat 1.9.0

Дата релиза: 2019-05-21

CСсылка на подробное описание релиза: [Link](https://github.com/selesnow/rfacebookstat/releases/tag/1.9.0)

## Что нового

* Новая функция `fbGetCatalogs` предназначенная для загрузки каталогов;
* Опции, для упрощения и компактности синтаксиса в пакет добавлены 4 опции
    * rfacebookstat.api_version - Версия API, по умолчанию v3.3
	* rfacebookstat.access_token - Токен доступа к API
	* rfacebookstat.accounts_id - ID рекламного аккаунта
	* rfacebookstat.business_id - ID бизнес менеджера
* Упрощённый формат фильтрации данных, пример `"impressions LESS_THAN 5000"`;
* Исправлена ошибка возникающая при загрузке action и применения action_breakdowns;
* В пакет добавлена виньетка посвящённая загрузки статистики из рекламных аккаунтов Facebook: `vignette('rfacebookstat-get-statistics', package = 'rfacebookstat')`;
* Добавлен обработчик лимитов API;
* В результат возвращаемый функцией `fbGetAdCreative` добавлено поле *link_nested* с данными по дочерним ссылкам из кольцевой галереи.
